## $Id: browser.py 8196 2012-04-17 12:14:03Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""UI components for basic applicants and related components.
"""
import grok
from waeup.kofa.applicants.interfaces import (
    IApplicantRegisterUpdate, IApplicant, IApplicantEdit)
from waeup.kofa.applicants.browser import (ApplicantDisplayFormPage,
    OnlinePaymentCallbackPage, ExportPDFPage,
    ApplicantManageFormPage, ApplicantEditFormPage,
    ApplicantRegistrationPage, ApplicantAddFormPage)
from waeup.kofa.applicants.viewlets import RequestCallbackActionButton
from waeup.kofa.applicants.pdf import PDFApplicationSlip
from waeup.uniben.applicants.interfaces import (
    IPGApplicant, IUGApplicant, IPGApplicantEdit, IUGApplicantEdit)
from waeup.uniben.interfaces import MessageFactory as _

class CustomRequestCallbackActionButton(RequestCallbackActionButton):
    """ Do not display the base package callback button in custom pages.
    """
    @property
    def target_url(self):
        return ''

class CustomOnlinePaymentCallbackPage(OnlinePaymentCallbackPage):
    """ Neutralize callback simulation view
    """
    def update(self):
        return

class CustomPDFApplicationSlip(PDFApplicationSlip):

    @property
    def form_fields(self):
        target = getattr(self.context.__parent__, 'prefix', None)
        if target is not None and target.startswith('pg'):
            form_fields = grok.AutoFields(IPGApplicant).omit(
                'locked', 'course_admitted')
        else:
            form_fields = grok.AutoFields(IUGApplicant).omit(
                'locked', 'course_admitted')
        return form_fields

class CustomApplicantDisplayFormPage(ApplicantDisplayFormPage):
    """A display view for applicant data.
    """

    @property
    def form_fields(self):
        target = getattr(self.context.__parent__, 'prefix', None)
        if target is not None and target.startswith('pg'):
            form_fields = grok.AutoFields(IPGApplicant).omit(
                'locked', 'course_admitted', 'password')
        else:
            form_fields = grok.AutoFields(IUGApplicant).omit(
                'locked', 'course_admitted', 'password')
        return form_fields

class CustomApplicantManageFormPage(ApplicantManageFormPage):
    """A full edit view for applicant data.
    """
    
    @property
    def form_fields(self):
        target = getattr(self.context.__parent__, 'prefix', None)
        if target is not None and target.startswith('pg'):
            form_fields = grok.AutoFields(IPGApplicant)
        else:
            form_fields = grok.AutoFields(IUGApplicant)
        form_fields['student_id'].for_display = True
        form_fields['applicant_id'].for_display = True
        return form_fields

class CustomApplicantEditFormPage(ApplicantEditFormPage):
    """An applicant-centered edit view for applicant data.
    """

    @property
    def form_fields(self):
        target = getattr(self.context.__parent__, 'prefix', None)
        if target is not None and target.startswith('pg'):
            form_fields = grok.AutoFields(IPGApplicantEdit).omit(
                'locked', 'course_admitted', 'student_id',
                'screening_score', 'screening_venue'
                )
        else:
            form_fields = grok.AutoFields(IUGApplicantEdit).omit(
                'locked', 'course_admitted', 'student_id',
                'screening_score'
                )
        form_fields['applicant_id'].for_display = True
        form_fields['reg_number'].for_display = True
        return form_fields
